OC.L10N.register(
    "groupfolders",
    {
    "Denied (Inherited permission)" : "Ukatua (heredatutako baimena)",
    "Allowed (Inherited permission)" : "Baimenduta (heredatutako baimena)",
    "Denied" : "Ukatuta",
    "Allowed" : "Baimenduta",
    "Access denied" : "Sarbidea ukatua",
    "Access allowed" : "Sarbidea baimenduta",
    "Inherit permission" : "Heredatu baimena",
    "Deny" : "Ukatu",
    "Allow" : "Baimendu",
    "Group" : "Taldea",
    "Team" : "Lantaldea",
    "Read" : "Irakurri",
    "Write" : "Idatzi",
    "Create" : "Sortu",
    "Delete" : "Ezabatu",
    "Share" : "Partekatu",
    "You" : "Zu ",
    "Remove access rule" : "Kendu atzipen araua",
    "Select a user or group" : "Hautatu erabiltzaile edo talde bat",
    "Add group" : "Taldea gehitu",
    "Default" : "Lehenetsia",
    "Unlimited" : "Mugagabea",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Ziur zaude \"{folderName}\" eta bere barneko fitxategi guztiak ezabatu nahi dituzula? Eragiketa hau ezin da desegin",
    "Delete \"{folderName}\"?" : "Ezabatu \"{folderName}\"?",
    "Folder name" : "Karpetaren izena",
    "Quota" : "Kuota",
    "Advanced Permissions" : "Baimen aurreratuak",
    "Previous" : "Aurrekoa",
    "Next" : "Hurrengoa",
    "User" : "Erabiltzailea",
    "Unknown" : "Ezezaguna",
    "None" : "Bat ere ez",
    "{size} used" : "{size} erabilita",
    "Unset" : "Kendu ezarpena"
},
"nplurals=2; plural=(n != 1);");
